// /org/kde/plasma/private/mobileshell/NotificationBodyLabel.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _org_kde_plasma_private_mobileshell_NotificationBodyLabel_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x8,0x0,0x0,0x3c,0x4d,0x2a,0x49,
0x74,0x69,0x1c,0x21,0x99,0x8f,0x60,0x97,
0xa8,0x30,0xb,0xc8,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x70,0x2,0x0,0x0,
0x4,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x8,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x6,0x0,0x0,
0x18,0x1,0x0,0x0,0x80,0x1,0x0,0x0,
0xd0,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0x23,0x1,0x0,0x0,0x30,0x1,0x0,0x0,
0x43,0x1,0x0,0x0,0x50,0x1,0x0,0x0,
0x43,0x1,0x0,0x0,0x60,0x1,0x0,0x0,
0x43,0x1,0x0,0x0,0x70,0x1,0x0,0x0,
0x43,0x1,0x0,0x0,0x80,0x1,0x0,0x0,
0x93,0x1,0x0,0x0,0xa0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0xfd,0x3f,
0x44,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x18,0x7,0x10,0x1,0xa0,0x7,0x18,0x8,
0x6,0x6e,0x8,0x50,0x6,0x2e,0x2,0x3c,
0x3,0x4c,0x4,0x2e,0x4,0x3c,0x5,0x18,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x17,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x6,0x3c,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x18,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x8,0x3c,0x9,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xa,0x3c,0xb,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0xe0,0x2,0x0,0x0,0xe8,0x2,0x0,0x0,
0x0,0x3,0x0,0x0,0x28,0x3,0x0,0x0,
0x50,0x3,0x0,0x0,0x88,0x3,0x0,0x0,
0xc0,0x3,0x0,0x0,0xd8,0x3,0x0,0x0,
0xe8,0x3,0x0,0x0,0x8,0x4,0x0,0x0,
0x28,0x4,0x0,0x0,0x60,0x4,0x0,0x0,
0x88,0x4,0x0,0x0,0x98,0x4,0x0,0x0,
0xc8,0x4,0x0,0x0,0xe0,0x4,0x0,0x0,
0x18,0x5,0x0,0x0,0x38,0x5,0x0,0x0,
0x70,0x5,0x0,0x0,0x88,0x5,0x0,0x0,
0xb0,0x5,0x0,0x0,0xc0,0x5,0x0,0x0,
0xe0,0x5,0x0,0x0,0x8,0x6,0x0,0x0,
0x28,0x6,0x0,0x0,0x40,0x6,0x0,0x0,
0x58,0x6,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x57,0x0,0x69,0x0,
0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x61,0x0,
0x43,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,
0x6f,0x0,0x6e,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x61,0x0,
0x2e,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,
0x70,0x0,0x6f,0x0,0x6e,0x0,0x65,0x0,
0x6e,0x0,0x74,0x0,0x73,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x73,0x0,0x6d,0x0,0x61,0x0,
0x43,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,
0x6f,0x0,0x6e,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x73,0x0,0x2e,0x0,0x4c,0x0,
0x61,0x0,0x62,0x0,0x65,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x62,0x0,0x6f,0x0,
0x64,0x0,0x79,0x0,0x54,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x72,0x0,0x65,0x0,
0x6e,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x54,0x0,0x79,0x0,0x70,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x72,0x0,0x65,0x0,0x6e,0x0,
0x64,0x0,0x65,0x0,0x72,0x0,0x54,0x0,
0x79,0x0,0x70,0x0,0x65,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6d,0x0,0x61,0x0,
0x78,0x0,0x69,0x0,0x6d,0x0,0x75,0x0,
0x6d,0x0,0x4c,0x0,0x69,0x0,0x6e,0x0,
0x65,0x0,0x43,0x0,0x6f,0x0,0x75,0x0,
0x6e,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x65,0x0,0x6c,0x0,
0x69,0x0,0x64,0x0,0x65,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x65,0x0,0x6c,0x0,0x69,0x0,
0x64,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x77,0x0,0x72,0x0,
0x61,0x0,0x70,0x0,0x4d,0x0,0x6f,0x0,
0x64,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x77,0x0,0x72,0x0,0x61,0x0,
0x70,0x0,0x4d,0x0,0x6f,0x0,0x64,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x74,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x46,0x0,0x6f,0x0,
0x72,0x0,0x6d,0x0,0x61,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x65,0x0,0x78,0x0,
0x74,0x0,0x46,0x0,0x6f,0x0,0x72,0x0,
0x6d,0x0,0x61,0x0,0x74,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x53,0x0,0x63,0x0,
0x72,0x0,0x65,0x0,0x65,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x64,0x0,0x65,0x0,
0x76,0x0,0x69,0x0,0x63,0x0,0x65,0x0,
0x50,0x0,0x69,0x0,0x78,0x0,0x65,0x0,
0x6c,0x0,0x52,0x0,0x61,0x0,0x74,0x0,
0x69,0x0,0x6f,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x54,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x52,0x0,0x65,0x0,0x6e,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x4e,0x0,0x61,0x0,
0x74,0x0,0x69,0x0,0x76,0x0,0x65,0x0,
0x52,0x0,0x65,0x0,0x6e,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x45,0x0,0x6c,0x0,
0x69,0x0,0x64,0x0,0x65,0x0,0x52,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x57,0x0,0x6f,0x0,
0x72,0x0,0x64,0x0,0x57,0x0,0x72,0x0,
0x61,0x0,0x70,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x54,0x0,0x65,0x0,
0x78,0x0,0x74,0x0,0x45,0x0,0x64,0x0,
0x69,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x69,0x0,0x6e,0x0,0x54,0x0,
0x65,0x0,0x78,0x0,0x74,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x4c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0xc,0x0,0x10,0x0,
0x0,0x3,0x0,0x0,0x54,0x0,0x0,0x0,
0x3c,0x1,0x0,0x0,0x5,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x6,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0xe,0x0,0x10,0x0,0xf,0x0,0x50,0x0,
0xe4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x19,0x0,0x10,0x1,
0xe,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x50,0x0,0x18,0x0,0xf0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x50,0x0,0x17,0x0,0xc0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x50,0x0,0x16,0x0,0x70,0x1,
0x9,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x14,0x0,0x10,0x1,
0x8,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x50,0x0,0x11,0x0,0x10,0x1,
0x0,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x11,0x0,0x10,0x1,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickText::RenderType"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for renderType at line 20, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
bool v2_13;
double v2_2;
double v2_6;
double v2_8;
int c2_27;
int v2_12;
int v2_19;
int v2_25;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadAttachedLookup(0, aotContext->qmlScopeObject, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadAttachedLookup(0, QQmlPrivate::AOTCompiledContext::InvalidStringId, aotContext->qmlScopeObject);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickText::RenderType"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(1, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(1, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickText::RenderType"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_6 = double(1);
{
}
// generate_Mod
s.v2_8 = (QJSPrimitiveValue(s.v2_2) % QJSPrimitiveValue(s.v2_6)).toDouble();
{
}
// generate_StoreReg
{
}
// generate_LoadZero
s.v2_12 = 0;
{
}
// generate_CmpStrictNotEqual
s.v2_13 = s.v2_8 != double(s.v2_12);
{
}
// generate_JumpFalse
if (!s.v2_13) {
    goto label_0;
}
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(21);
#endif
while (!aotContext->getEnumLookup(3, &s.v2_19)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(21);
#endif
aotContext->initGetEnumLookup(3, []() { static const auto t = QMetaType::fromName("QQuickText*"); return t; }().metaObject(), "RenderType", "QtRendering");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickText::RenderType"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_Jump
{
s.c2_27 = s.v2_19;
    goto label_1;
}
label_0:;
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
while (!aotContext->getEnumLookup(5, &s.v2_25)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
aotContext->initGetEnumLookup(5, []() { static const auto t = QMetaType::fromName("QQuickText*"); return t; }().metaObject(), "RenderType", "NativeRendering");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickText::RenderType"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
s.c2_27 = s.v2_25;
}
label_1:;
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.c2_27);
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickText::TextElideMode"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for elide at line 23, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(7, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(7, []() { static const auto t = QMetaType::fromName("QQuickText*"); return t; }().metaObject(), "TextElideMode", "ElideRight");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickText::TextElideMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_2);
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickText::WrapMode"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for wrapMode at line 24, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(9, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(9, []() { static const auto t = QMetaType::fromName("QQuickText*"); return t; }().metaObject(), "WrapMode", "WordWrap");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickText::WrapMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_2);
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickText::TextFormat"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for textFormat at line 25, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(11, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(11, []() { static const auto t = QMetaType::fromName("QQuickTextEdit*"); return t; }().metaObject(), "TextFormat", "PlainText");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickText::TextFormat"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_2);
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
