/****************************************************************************
** Meta object code from reading C++ file 'signalindicator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-mobile-6.6.5/components/mmplugin/signalindicator.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'signalindicator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15SignalIndicatorE_t {};
} // unnamed namespace

template <> constexpr inline auto SignalIndicator::qt_create_metaobjectdata<qt_meta_tag_ZN15SignalIndicatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignalIndicator",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "strengthChanged",
        "",
        "nameChanged",
        "modemAvailableChanged",
        "simLockedChanged",
        "simEmptyChanged",
        "mobileDataSupportedChanged",
        "mobileDataEnabledChanged",
        "profileListChanged",
        "activeConnectionUniChanged",
        "activateProfile",
        "QCoro::Task<void>",
        "connectionUni",
        "addProfile",
        "name",
        "apn",
        "username",
        "password",
        "networkType",
        "removeProfile",
        "updateProfile",
        "strength",
        "modemAvailable",
        "simLocked",
        "simEmpty",
        "mobileDataSupported",
        "mobileDataEnabled",
        "needsAPNAdded",
        "profiles",
        "QList<ProfileSettings*>",
        "activeConnectionUni"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'strengthChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modemAvailableChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'simLockedChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'simEmptyChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mobileDataSupportedChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mobileDataEnabledChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profileListChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeConnectionUniChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'activateProfile'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &)>(15, 6, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'addProfile'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &, const QString &, const QString &, const QString &, const QString &)>(18, 6, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
            { QMetaType::QString, 23 },
        }}),
        // Method 'removeProfile'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &)>(24, 6, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 17 },
        }}),
        // Method 'updateProfile'
        QtMocHelpers::MethodData<QCoro::Task<void>(const QString &, const QString &, const QString &, const QString &, const QString &, const QString &)>(25, 6, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 }, { QMetaType::QString, 21 },
            { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'strength'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'modemAvailable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'simLocked'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'simEmpty'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'mobileDataSupported'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'mobileDataEnabled'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'needsAPNAdded'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'profiles'
        QtMocHelpers::PropertyData<QList<ProfileSettings*>>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'activeConnectionUni'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<SignalIndicator, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SignalIndicator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SignalIndicatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SignalIndicatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15SignalIndicatorE_t>.metaTypes,
    nullptr
} };

void SignalIndicator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignalIndicator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->strengthChanged(); break;
        case 1: _t->nameChanged(); break;
        case 2: _t->modemAvailableChanged(); break;
        case 3: _t->simLockedChanged(); break;
        case 4: _t->simEmptyChanged(); break;
        case 5: _t->mobileDataSupportedChanged(); break;
        case 6: _t->mobileDataEnabledChanged(); break;
        case 7: _t->profileListChanged(); break;
        case 8: _t->activeConnectionUniChanged(); break;
        case 9: { QCoro::Task<void> _r = _t->activateProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QCoro::Task<void> _r = _t->addProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QCoro::Task<void> _r = _t->removeProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QCoro::Task<void> _r = _t->updateProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::strengthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::modemAvailableChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::simLockedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::simEmptyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::mobileDataSupportedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::mobileDataEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::profileListChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignalIndicator::*)()>(_a, &SignalIndicator::activeConnectionUniChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<ProfileSettings*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->strength(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->modemAvailable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->simLocked(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->simEmpty(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->mobileDataSupported(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->mobileDataEnabled(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->needsAPNAdded(); break;
        case 8: *reinterpret_cast<QList<ProfileSettings*>*>(_v) = _t->profileList(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->activeConnectionUni(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setMobileDataEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *SignalIndicator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignalIndicator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15SignalIndicatorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SignalIndicator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void SignalIndicator::strengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SignalIndicator::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SignalIndicator::modemAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SignalIndicator::simLockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SignalIndicator::simEmptyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SignalIndicator::mobileDataSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void SignalIndicator::mobileDataEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SignalIndicator::profileListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SignalIndicator::activeConnectionUniChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
